@@ -1,4 +1,13 @@
-# $Id: Tinylink.pm,v 1.89 2004/10/30 12:52:01 dave Exp $
+# $Id: Tinylink.pm 60 2007-04-15 19:05:34Z dave $
+
+use strict;
+use warnings;
+
+our $VERSION = '1.91';
+require WWW::Shorten::_dead;
+
+0;
+__END__
 
 =head1 NAME
 
@@ -6,12 +15,7 @@ WWW::Shorten::Tinylink - Perl interface to Tinylink.com
 
 =head1 SYNOPSIS
 
-  use WWW::Shorten 'Tinylink';
-
-  $short_url = makeashorterlink($long_url);
-
-  $long_url  = makealongerlink($short_url);
-  $long_url  = makealongerlink($nickname);
+  # No appropriate solution
 
 =head1 DESCRIPTION
 
@@ -19,6 +23,9 @@ A Perl interface to the web site Tinylink.com. Tinylink.com simply
 maintains a database of long URLs, each of which has a unique
 identifier.
 
+Unfortunately, at some point in the middle of 2088, Tinylink.com stopped
+returning useable URLs and therefore this module is now deprecated.
+
 =cut
 
 package WWW::Shorten::Tinylink;
@@ -29,7 +36,7 @@ use warnings;
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = sprintf "%d.%02d", '$Revision: 1.89 $ ' =~ /(\d+)\.(\d+)/;
+our $VERSION = '1.90';
 
 use Carp;
 
